"""Package pdfsyntax"""

from .api import *

__all__ = []
